@@ -23,10 +23,9 @@ import requests
 import socket
 from urllib.parse import urlparse
 import xmlrpc.client
-import yaml
 
 from .__about__ import __version__
-from .utils import loader, parse_version, VERSION_LATEST, exc2str
+from .utils import parse_version, VERSION_LATEST, exc2str, safe_yaml
 
 from .commands import (
     aliases,
@@ -35,6 +34,7 @@ from .commands import (
     events,
     identities,
     jobs,
+    lab,
     results,
     system,
     tags,
@@ -104,9 +104,7 @@ def load_config(identity):
 
     try:
         with open(config_filename, "r", encoding="utf-8") as f_conf:
-            config = yaml.load(  # nosec - loader() returns a safe loader
-                f_conf.read(), Loader=loader()
-            )
+            config = safe_yaml.load(f_conf.read())
         return config[identity]
     except (FileNotFoundError, KeyError, TypeError):
         return {}
@@ -171,6 +169,7 @@ def main():
         "events": events,
         "identities": identities,
         "jobs": jobs,
+        "lab": lab,
         "results": results,
         "system": system,
         "tags": tags,
