@@ -19,7 +19,9 @@
 
 import argparse
 import json
-import yaml
+import sys
+
+from lavacli.utils import safe_yaml
 
 
 def configure_parser(parser, version):
@@ -101,6 +103,12 @@ def configure_parser(parser, version):
         dt_hc = sub.add_parser("health-check", help="device-type health-check")
         dt_sub = dt_hc.add_subparsers(dest="sub_sub_sub_command", help="Sub commands")
         dt_sub.required = True
+        if version >= (2022, 4):
+            dt_delete = dt_sub.add_parser(
+                "delete", help="delete the device-type health-check"
+            )
+            dt_delete.add_argument("name", help="name of the device-type")
+
         dt_get = dt_sub.add_parser("get", help="get the device-type health-check")
         dt_get.add_argument("name", help="name of the device-type")
 
@@ -163,6 +171,12 @@ def configure_parser(parser, version):
     dt_template = sub.add_parser("template", help="device-type template")
     dt_sub = dt_template.add_subparsers(dest="sub_sub_sub_command", help="Sub commands")
     dt_sub.required = True
+    if version >= (2022, 4):
+        dt_delete = dt_sub.add_parser(
+            "delete", help="delete the custom device-type template"
+        )
+        dt_delete.add_argument("name", help="name of the device-type")
+
     dt_get = dt_sub.add_parser("get", help="get the device-type template")
     dt_get.add_argument("name", help="name of the device-type")
 
@@ -260,7 +274,7 @@ def handle_aliases(proxy, options, _):
         if options.output_format == "json":
             print(json.dumps(aliases))
         elif options.output_format == "yaml":
-            print(yaml.dump(aliases, default_flow_style=None).rstrip("\n"))
+            safe_yaml.dump(aliases, sys.stdout)
         else:
             print("Aliases:")
             for alias in aliases:
@@ -272,7 +286,9 @@ def handle_aliases(proxy, options, _):
 
 
 def handle_hc(proxy, options, _):
-    if options.sub_sub_sub_command == "get":
+    if options.sub_sub_sub_command == "delete":
+        template = proxy.scheduler.device_types.set_health_check(options.name, "")
+    elif options.sub_sub_sub_command == "get":
         template = proxy.scheduler.device_types.get_health_check(options.name)
         print(str(template).rstrip("\n"))
     else:
@@ -287,7 +303,7 @@ def handle_list(proxy, options, _):
     if options.output_format == "json":
         print(json.dumps(device_types))
     elif options.output_format == "yaml":
-        print(yaml.dump(device_types, default_flow_style=None).rstrip("\n"))
+        safe_yaml.dump(device_types, sys.stdout)
     else:
         print("Device-Types:")
         for dt in device_types:
@@ -301,7 +317,7 @@ def handle_show(proxy, options, config):
     if options.output_format == "json":
         print(json.dumps(dt))
     elif options.output_format == "yaml":
-        print(yaml.dump(dt, default_flow_style=None).rstrip("\n"))
+        safe_yaml.dump(dt, sys.stdout)
     else:
         print("name            : %s" % dt["name"])
         print("description     : %s" % dt["description"])
@@ -315,7 +331,9 @@ def handle_show(proxy, options, config):
 
 
 def handle_template(proxy, options, _):
-    if options.sub_sub_sub_command == "get":
+    if options.sub_sub_sub_command == "delete":
+        template = proxy.scheduler.device_types.set_template(options.name, "")
+    elif options.sub_sub_sub_command == "get":
         template = proxy.scheduler.device_types.get_template(options.name)
         print(str(template).rstrip("\n"))
     else:
