@@ -20,9 +20,9 @@
 import argparse
 import json
 import time
-import yaml
+import sys
 
-from lavacli.utils import loader
+from lavacli.utils import safe_yaml
 
 
 def configure_parser(parser, version):
@@ -74,6 +74,10 @@ def configure_parser(parser, version):
         dest="sub_sub_sub_command", help="Sub commands"
     )
     dict_sub.required = True
+    if version >= (2022, 4):
+        dict_delete = dict_sub.add_parser("delete", help="delete the device dictionary")
+        dict_delete.add_argument("name", help="name of the device")
+
     dict_get = dict_sub.add_parser("get", help="get the device dictionary")
     dict_get.add_argument("name", help="name of the device")
     dict_get.add_argument(
@@ -290,7 +294,10 @@ def _lookups(value, fields):
 
 
 def handle_dict(proxy, options, _):
-    if options.sub_sub_sub_command == "get":
+    if options.sub_sub_sub_command == "delete":
+        proxy.scheduler.devices.set_dictionary(options.name, "")
+        return 0
+    elif options.sub_sub_sub_command == "get":
         config = proxy.scheduler.devices.get_dictionary(
             options.name, options.render, options.context
         )
@@ -299,9 +306,7 @@ def handle_dict(proxy, options, _):
             return 0
 
         if options.render:
-            value = yaml.load(  # nosec - loader() returns a safe loader
-                str(config), Loader=loader()
-            )
+            value = safe_yaml.load(str(config))
             return _lookups(value, options.field.split("."))
         else:
             # Extract some variables
@@ -337,7 +342,7 @@ def handle_list(proxy, options, config):
     if options.output_format == "json":
         print(json.dumps(devices))
     elif options.output_format == "yaml":
-        print(yaml.dump(devices, default_flow_style=None).rstrip("\n"))
+        safe_yaml.dump(devices, sys.stdout)
     else:
         print("Devices:")
         for device in devices:
@@ -386,7 +391,7 @@ def handle_show(proxy, options, config):
     if options.output_format == "json":
         print(json.dumps(device))
     elif options.output_format == "yaml":
-        print(yaml.dump(device, default_flow_style=None).rstrip("\n"))
+        safe_yaml.dump(device, sys.stdout)
     else:
         print("name        : %s" % device["hostname"])
         print("device-type : %s" % device["device_type"])
@@ -420,7 +425,7 @@ def handle_tags(proxy, options, _):
         if options.output_format == "json":
             print(json.dumps(tags))
         elif options.output_format == "yaml":
-            print(yaml.dump(tags, default_flow_style=None).rstrip("\n"))
+            safe_yaml.dump(tags, sys.stdout)
         else:
             print("Tags:")
             for tag in tags:
