@@ -26,9 +26,8 @@ import sys
 import time
 from urllib.parse import urlparse
 import xmlrpc.client
-import yaml
 
-from lavacli.utils import dumper, loader, print_u, exc2str
+from lavacli.utils import exc2str, log_yaml, safe_yaml
 
 
 def configure_log_options(parser):
@@ -358,7 +357,7 @@ def handle_list(proxy, options, config):
     if options.output_format == "json":
         print(json.dumps(jobs))
     elif options.output_format == "yaml":
-        print(yaml.dump(jobs, default_flow_style=None).rstrip("\n"))
+        safe_yaml.dump(jobs, sys.stdout)
     else:
         print(
             "Jobs (from %s to %s):" % (1 + options.start, options.start + options.limit)
@@ -460,15 +459,10 @@ def print_logs(logs, raw, filters):
         for line in logs:
             if filters and not line["lvl"] in filters:
                 continue
-            print_u(
-                "- "
-                + yaml.dump(
-                    line,
-                    default_flow_style=True,
-                    default_style='"',
-                    width=10 ** 6,
-                    Dumper=dumper(),
-                )[:-1]
+            sys.stdout.write("- ")
+            log_yaml.dump(
+                line,
+                sys.stdout,
             )
     else:
         for line in logs:
@@ -488,7 +482,7 @@ def print_logs(logs, raw, filters):
             ns = ""
             if level == "feedback" and "ns" in line:
                 ns = " <" + COLORS["feedback"] + line["ns"] + COLORS["end"] + ">"
-            print_u(
+            print(
                 COLORS["dt"]
                 + timestamp
                 + COLORS["end"]
@@ -503,10 +497,10 @@ def print_logs(logs, raw, filters):
 def _download_logs(proxy, version, job_id, start, end):
     if version >= (2018, 6):
         (finished, data) = proxy.scheduler.jobs.logs(job_id, start, end)
-        logs = yaml.load(str(data), Loader=loader(False))
+        logs = safe_yaml.load(str(data))
     else:
         (finished, data) = proxy.scheduler.jobs.logs(job_id, start)
-        logs = yaml.load(str(data), Loader=loader(False))
+        logs = safe_yaml.load(str(data))
         if end is not None and len(logs) >= end - start:
             if end < start:
                 end = start
@@ -565,7 +559,7 @@ def handle_queue(proxy, options, config):
     if options.output_format == "json":
         print(json.dumps(data))
     elif options.output_format == "yaml":
-        print(yaml.dump(data, default_flow_style=None).rstrip("\n"))
+        safe_yaml.dump(data, sys.stdout)
     else:
         print(
             "Jobs (from %s to %s):" % (1 + options.start, options.start + options.limit)
@@ -688,7 +682,7 @@ def handle_show(proxy, options, config):
         job["submit_time"] = job["submit_time"].value if job["submit_time"] else None
         job["start_time"] = job["start_time"].value if job["start_time"] else None
         job["end_time"] = job["end_time"].value if job["end_time"] else None
-        print(yaml.dump(job, default_flow_style=None).rstrip("\n"))
+        safe_yaml.dump(job, sys.stdout)
     else:
         print("id          : %s" % job["id"])
         print("description : %s" % job["description"])
