@@ -19,9 +19,8 @@
 
 import contextlib
 from dataclasses import asdict, dataclass, field, fields, MISSING
-import os
+import difflib
 from pathlib import Path
-import subprocess
 from typing import Any, Dict, List, Set
 import xmlrpc
 
@@ -30,6 +29,16 @@ import ruamel.yaml
 from lavacli import colors
 
 
+def print_file_diff(src, dst):
+    if src is None:
+        print("    | + None")
+    elif dst is None:
+        print("    | - None")
+    else:
+        diffs = difflib.unified_diff(src.split("\n"), dst.split("\n"), lineterm="")
+        print("    | " + "\n    | ".join(list(diffs)[2:]))
+
+
 class Base:
     @classmethod
     def new(cls, **kwargs):
@@ -338,12 +347,13 @@ def handle_apply(proxy, options, config):
                 hc = None
             if dt.get_health_check(base) != hc:
                 print(f"    {colors.yellow}-> health-check{colors.reset}")
+                print_file_diff(hc, dt.get_health_check(base))
                 if not options.dry_run:
                     proxy.scheduler.device_types.set_health_check(
                         dt.name, dt.get_health_check(base)
                     )
 
-            if dt.get_template(base) is not None:
+            if not data["default_template"] or dt.get_template(base) is not None:
                 try:
                     template = str(proxy.scheduler.device_types.get_template(dt.name))
                 except xmlrpc.client.Fault as exc:
@@ -352,6 +362,7 @@ def handle_apply(proxy, options, config):
                     template = None
                 if dt.get_template(base) != template:
                     print(f"    {colors.yellow}-> template{colors.reset}")
+                    print_file_diff(template, dt.get_template(base))
                     if not options.dry_run:
                         proxy.scheduler.device_types.set_template(
                             dt.name, dt.template(base)
@@ -385,40 +396,48 @@ def handle_apply(proxy, options, config):
                     worker.job_limit if "job_limit" in diff else None,
                 )
 
-            try:
-                wconfig = str(proxy.scheduler.workers.get_config(worker.hostname))
-            except xmlrpc.client.Fault as exc:
-                if exc.faultCode != 404:
-                    raise
-                wconfig = None
-            if worker.get_config(base) != wconfig:
-                print(f"    {colors.yellow}-> config{colors.reset}")
-                if not options.dry_run:
-                    proxy.scheduler.workers.set_config(dt.name, worker.get_config(base))
+            if not data["default_config"] or worker.get_config(base) is not None:
+                try:
+                    wconfig = str(proxy.scheduler.workers.get_config(worker.hostname))
+                except xmlrpc.client.Fault as exc:
+                    if exc.faultCode != 404:
+                        raise
+                    wconfig = None
+                if worker.get_config(base) != wconfig:
+                    print(f"    {colors.yellow}-> config{colors.reset}")
+                    print_file_diff(wconfig, worker.get_config(base))
+                    if not options.dry_run:
+                        proxy.scheduler.workers.set_config(
+                            dt.name, worker.get_config(base)
+                        )
 
-            try:
-                wenv = str(proxy.scheduler.workers.get_env(worker.hostname))
-            except xmlrpc.client.Fault as exc:
-                if exc.faultCode != 404:
-                    raise
-                wenv = None
-            if worker.get_env(base) != wenv:
-                print(f"    {colors.yellow}-> env{colors.reset}")
-                if not options.dry_run:
-                    proxy.scheduler.workers.set_env(dt.name, worker.get_env(base))
+            if not data["default_env"] or worker.get_env(base) is not None:
+                try:
+                    wenv = str(proxy.scheduler.workers.get_env(worker.hostname))
+                except xmlrpc.client.Fault as exc:
+                    if exc.faultCode != 404:
+                        raise
+                    wenv = None
+                if worker.get_env(base) != wenv:
+                    print(f"    {colors.yellow}-> env{colors.reset}")
+                    print_file_diff(wenv, worker.get_env(base))
+                    if not options.dry_run:
+                        proxy.scheduler.workers.set_env(dt.name, worker.get_env(base))
 
-            try:
-                wenv_dut = str(proxy.scheduler.workers.get_env_dut(worker.hostname))
-            except xmlrpc.client.Fault as exc:
-                if exc.faultCode != 404:
-                    raise
-                wenv_dut = None
-            if worker.get_env_dut(base) != wenv_dut:
-                print(f"    {colors.yellow}-> env-dut{colors.reset}")
-                if not options.dry_run:
-                    proxy.scheduler.workers.set_env_dut(
-                        dt.name, worker.get_env_dut(base)
-                    )
+            if not data["default_env_dut"] or worker.get_env_dut(base) is not None:
+                try:
+                    wenv_dut = str(proxy.scheduler.workers.get_env_dut(worker.hostname))
+                except xmlrpc.client.Fault as exc:
+                    if exc.faultCode != 404:
+                        raise
+                    wenv_dut = None
+                if worker.get_env_dut(base) != wenv_dut:
+                    print(f"    {colors.yellow}-> env-dut{colors.reset}")
+                    print_file_diff(wenv_dut, worker.get_env_dut(base))
+                    if not options.dry_run:
+                        proxy.scheduler.workers.set_env_dut(
+                            dt.name, worker.get_env_dut(base)
+                        )
 
     print(f"{colors.cyan}> devices{colors.reset}")
     if "devices" not in options.resources:
@@ -481,6 +500,7 @@ def handle_apply(proxy, options, config):
 
             if device.get_dict(base) != ddict:
                 print(f"    {colors.yellow}-> dictionary{colors.reset}")
+                print_file_diff(ddict, device.get_dict(base))
                 if not options.dry_run:
                     proxy.scheduler.devices.set_dictionary(
                         device.hostname, device.get_dict(base)
@@ -508,7 +528,7 @@ def handle_import(proxy, options, config):
             print(f"  {colors.green}  -> health-check{colors.reset}")
             lab.device_types[dt].set_health_check(base, hc)
 
-        if data.get("default_template", False):
+        if data["default_template"]:
             print(f"  {colors.green}  -> default template{colors.reset}")
         else:
             try:
@@ -528,7 +548,7 @@ def handle_import(proxy, options, config):
         data = proxy.scheduler.workers.show(worker)
         lab.workers[worker] = Worker.new(**data)
 
-        if data.get("default_config", False):
+        if data["default_config"]:
             print(f"  {colors.green}  -> default config{colors.reset}")
         else:
             try:
@@ -541,7 +561,7 @@ def handle_import(proxy, options, config):
                 print(f"  {colors.green}  -> config{colors.reset}")
                 lab.workers[worker].set_config(base, wconfig)
 
-        if data.get("default_env", False):
+        if data["default_env"]:
             print(f"  {colors.green}  -> default env{colors.reset}")
         else:
             try:
@@ -554,7 +574,7 @@ def handle_import(proxy, options, config):
                 print(f"  {colors.green}  -> env{colors.reset}")
                 lab.workers[worker].set_env(base, wenv)
 
-        if data.get("default_env_dut", False):
+        if data["default_env_dut"]:
             print(f"  {colors.green}  -> default env-dut{colors.reset}")
         else:
             try:
