@@ -19,9 +19,8 @@
 
 import json
 import sys
-import yaml
 
-from lavacli.utils import loader
+from lavacli.utils import safe_yaml
 
 
 def configure_parser(parser, _):
@@ -63,12 +62,12 @@ def handle(proxy, options, _):
     else:
         data = proxy.results.get_testjob_results_yaml(options.job_id)
 
-    results = yaml.load(data, Loader=loader())  # nosec - loader() returns a safe loader
+    results = safe_yaml.load(data)
 
     if options.output_format == "json":
         print(json.dumps(results))
     elif options.output_format == "yaml":
-        print(yaml.dump(results, default_flow_style=None).rstrip("\n"))
+        safe_yaml.dump(results, sys.stdout)
     else:
         # Only print the result
         if options.test_case is not None:
