@@ -22,7 +22,8 @@ import pathlib
 import shutil
 import time
 import xmlrpc.client
-import yaml
+
+from lavacli.utils import flow_yaml, safe_yaml
 
 
 def configure_parser(parser, version):
@@ -224,7 +225,7 @@ def handle_export(proxy, options, config):
 
     # Dump the configuration
     with (dest / "instance.yaml").open("w", encoding="utf-8") as f_out:
-        f_out.write(yaml.dump(export, default_flow_style=None).rstrip("\n"))
+        flow_yaml.dump(export, f_out)
     return 0
 
 
