@@ -18,7 +18,9 @@
 # along with lavacli.  If not, see <http://www.gnu.org/licenses/>
 
 import json
-import yaml
+import sys
+
+from lavacli.utils import safe_yaml
 
 
 def configure_parser(parser, _):
@@ -93,7 +95,7 @@ def handle_list(proxy, options):
     if options.output_format == "json":
         print(json.dumps(tags))
     elif options.output_format == "yaml":
-        print(yaml.dump(tags, default_flow_style=None).rstrip("\n"))
+        safe_yaml.dump(tags, sys.stdout)
     else:
         print("Tags:")
         for tag in tags:
@@ -109,7 +111,7 @@ def handle_show(proxy, options):
     if options.output_format == "json":
         print(json.dumps(tag))
     elif options.output_format == "yaml":
-        print(yaml.dump(tag, default_flow_style=None).rstrip("\n"))
+        safe_yaml.dump(tag, sys.stdout)
     else:
         print("name       : %s" % tag["name"])
         print("description: %s" % tag["description"])
