@@ -20,9 +20,9 @@
 import argparse
 import jinja2
 from pathlib import Path
-import yaml
 
-from lavacli.utils import loader
+from lavacli.utils import safe_yaml
+
 from . import jobs
 
 
@@ -78,8 +78,8 @@ def help_string():
 
 def handle_logs(_, options):
     try:
-        logs = yaml.load(options.filename.read(), Loader=loader(False))
-    except yaml.YAMLError:
+        logs = safe_yaml.load(options.filename.read())
+    except ruamel.yaml.YAMLError:
         print("Invalid yaml file")
     else:
         jobs.print_logs(logs, options.raw, options.filters)
