@@ -19,18 +19,22 @@
 
 import re
 import xmlrpc.client
-import yaml
 
-
-def print_u(string):
-    try:
-        print(string)
-    except UnicodeEncodeError:
-        print(string.encode("ascii", errors="replace").decode("ascii"))
+from ruamel.yaml import YAML
 
 
 VERSION_LATEST = (3000, 1)
 
+# yaml objects
+
+flow_yaml = YAML(typ="safe")
+flow_yaml.default_flow_style = False
+log_yaml = YAML(typ="safe")
+log_yaml.default_flow_style = True
+log_yaml.default_style = '"'
+log_yaml.width = 10 ** 6
+safe_yaml = YAML(typ="safe")
+
 
 def parse_version(version):
     pattern = re.compile(r"(?P<major>20\d{2})\.(?P<minor>\d{1,2})")
@@ -43,21 +47,6 @@ def parse_version(version):
     return (int(res["major"]), int(res["minor"]))
 
 
-def loader(safe=True):
-    try:
-        return yaml.CSafeLoader if safe else yaml.CLoader
-    except AttributeError:
-        # TODO log a warning on stderr
-        return yaml.SafeLoader if safe else yaml.Loader
-
-
-def dumper():
-    try:
-        return yaml.CDumper
-    except AttributeError:
-        return yaml.Dumper
-
-
 def exc2str(exc):
     if isinstance(exc, xmlrpc.client.ProtocolError):
         return exc.errmsg
