@@ -21,7 +21,6 @@ import json
 import pytest
 import sys
 import xmlrpc.client
-import yaml
 
 from lavacli import main
 
@@ -209,6 +208,35 @@ def test_dt_aliases_list_empty(setup, monkeypatch, capsys):
     assert capsys.readouterr()[0] == "Aliases:\n"  # nosec
 
 
+def test_dt_hc_delete(setup, monkeypatch, capsys, tmpdir):
+    version = "2022.4"
+    monkeypatch.setattr(
+        sys,
+        "argv",
+        [
+            "lavacli",
+            "device-types",
+            "health-check",
+            "delete",
+            "mydt",
+        ],
+    )
+    monkeypatch.setattr(
+        xmlrpc.client.ServerProxy,
+        "data",
+        [
+            {"request": "system.version", "args": (), "ret": version},
+            {
+                "request": "scheduler.device_types.set_health_check",
+                "args": ("mydt", ""),
+                "ret": None,
+            },
+        ],
+    )
+    assert main() == 0  # nosec
+    assert capsys.readouterr()[0] == ""  # nosec
+
+
 def test_dt_hc_get_before_2018_4(setup, monkeypatch, capsys):
     version = "2018.2"
     monkeypatch.setattr(
@@ -517,6 +545,35 @@ owners_only: false
     )
 
 
+def test_dt_template_delete(setup, monkeypatch, capsys, tmpdir):
+    version = "2022.4"
+    monkeypatch.setattr(
+        sys,
+        "argv",
+        [
+            "lavacli",
+            "device-types",
+            "template",
+            "delete",
+            "bbb",
+        ],
+    )
+    monkeypatch.setattr(
+        xmlrpc.client.ServerProxy,
+        "data",
+        [
+            {"request": "system.version", "args": (), "ret": version},
+            {
+                "request": "scheduler.device_types.set_template",
+                "args": ("bbb", ""),
+                "ret": None,
+            },
+        ],
+    )
+    assert main() == 0  # nosec
+    assert capsys.readouterr()[0] == ""  # nosec
+
+
 def test_dt_template_get(setup, monkeypatch, capsys):
     version = "2018.4"
     monkeypatch.setattr(
