@@ -19,9 +19,11 @@
 
 import sys
 import xmlrpc.client
-import yaml
+
+import ruamel.yaml
 
 from lavacli import main
+from lavacli.utils import safe_yaml
 
 
 def test_identities_add(setup, monkeypatch, capsys, tmpdir):
@@ -42,7 +44,7 @@ def test_identities_add(setup, monkeypatch, capsys, tmpdir):
     assert capsys.readouterr()[0] == ""  # nosec
 
     with (tmpdir / "lavacli.yaml").open() as f_in:
-        data = yaml.safe_load(f_in)
+        data = safe_yaml.load(f_in)
         assert set(data.keys()) == set(["default", "v.l.o"])  # nosec
         assert data["default"] == {"uri": "https://lava.example.com/RPC2"}  # nosec
         assert data["v.l.o"] == {"uri": "https://validation.linaro.org/RPC2"}  # nosec
@@ -72,7 +74,7 @@ def test_identities_add_1(setup, monkeypatch, capsys, tmpdir):
     assert capsys.readouterr()[0] == ""  # nosec
 
     with (tmpdir / "lavacli.yaml").open() as f_in:
-        data = yaml.safe_load(f_in)
+        data = safe_yaml.load(f_in)
         assert set(data.keys()) == set(["default", "v.l.o"])  # nosec
         assert data["default"] == {"uri": "https://lava.example.com/RPC2"}  # nosec
         assert data["v.l.o"] == {  # nosec
@@ -102,7 +104,7 @@ def test_identities_add_empty_config(setup, monkeypatch, capsys, tmpdir):
     assert capsys.readouterr()[0] == ""  # nosec
 
     with (tmpdir / "lavacli.yaml").open() as f_in:
-        data = yaml.safe_load(f_in)
+        data = safe_yaml.load(f_in)
         assert set(data.keys()) == set(["v.l.o"])  # nosec
         assert data["v.l.o"] == {"uri": "https://validation.linaro.org/RPC2"}  # nosec
 
@@ -118,7 +120,7 @@ def test_identities_delete(setup, monkeypatch, capsys, tmpdir):
     assert capsys.readouterr()[0] == ""  # nosec
 
     with (tmpdir / "lavacli.yaml").open() as f_in:
-        data = yaml.safe_load(f_in)
+        data = safe_yaml.load(f_in)
         assert list(data.keys()) == ["default"]  # nosec
         assert data["default"] == {"uri": "https://lava.example.com/RPC2"}  # nosec
 
@@ -139,7 +141,7 @@ def test_identities_delete_missing_key(setup, monkeypatch, capsys, tmpdir):
     assert capsys.readouterr()[0] == "Unknown identity 'v.l.o'\n"  # nosec
 
     with (tmpdir / "lavacli.yaml").open() as f_in:
-        data = yaml.safe_load(f_in)
+        data = safe_yaml.load(f_in)
         assert list(data.keys()) == ["default"]  # nosec
         assert data["default"] == {"uri": "https://lava.example.com/RPC2"}  # nosec
 
@@ -151,7 +153,7 @@ def test_identities_list(setup, monkeypatch, capsys, tmpdir):
     assert capsys.readouterr()[0] == "Identities:\n* default\n"  # nosec
 
     with (tmpdir / "lavacli.yaml").open() as f_in:
-        data = yaml.safe_load(f_in)
+        data = safe_yaml.load(f_in)
         assert list(data.keys()) == ["default"]  # nosec
         assert data["default"] == {"uri": "https://lava.example.com/RPC2"}  # nosec
 
@@ -167,7 +169,7 @@ def test_identities_list_1(setup, monkeypatch, capsys, tmpdir):
     assert capsys.readouterr()[0] == "Identities:\n* default\n* v.l.o\n"  # nosec
 
     with (tmpdir / "lavacli.yaml").open() as f_in:
-        data = yaml.safe_load(f_in)
+        data = safe_yaml.load(f_in)
         assert set(data.keys()) == set(["default", "v.l.o"])  # nosec
         assert data["default"] == {"uri": "https://lava.example.com/RPC2"}  # nosec
         assert data["v.l.o"] == {"uri": "https://validation.linaro.org/RPC2"}  # nosec
