@@ -21,9 +21,9 @@ import json
 import sys
 import time
 import xmlrpc.client
-import yaml
 
 from lavacli import main
+from lavacli.utils import safe_yaml
 
 
 def test_jobs_cancel(setup, monkeypatch, capsys):
@@ -620,7 +620,7 @@ def test_jobs_logs(setup, monkeypatch, capsys):
         == "2018-04-23T12:07:02 lava-dispatcher, installed at version: 2018.4-1"
     )
     assert lines[1][:20] == "2018-04-23T12:07:02 "  # nosec
-    assert yaml.safe_load(lines[1][20:]) == {  # nosec
+    assert safe_yaml.load(lines[1][20:]) == {  # nosec
         "case": "validate",
         "definition": "lava",
         "result": "pass",
@@ -694,7 +694,7 @@ def test_jobs_logs_failure_comment_and_polling(setup, monkeypatch, capsys):
         == "2018-04-23T12:07:02 lava-dispatcher, installed at version: 2018.4-1"
     )
     assert lines[1][:20] == "2018-04-23T12:07:02 "  # nosec
-    assert yaml.safe_load(lines[1][20:]) == {  # nosec
+    assert safe_yaml.load(lines[1][20:]) == {  # nosec
         "case": "validate",
         "definition": "lava",
         "result": "pass",
@@ -1312,7 +1312,7 @@ def test_jobs_run(setup, monkeypatch, capsys, tmpdir):
         == "2018-04-23T12:07:02 lava-dispatcher, installed at version: 2018.4-1"
     )
     assert lines[2][:20] == "2018-04-23T12:07:02 "  # nosec
-    assert yaml.safe_load(lines[2][20:]) == {  # nosec
+    assert safe_yaml.load(lines[2][20:]) == {  # nosec
         "case": "validate",
         "definition": "lava",
         "result": "pass",
@@ -1675,13 +1675,12 @@ def test_jobs_submit_url_identity_admin(setup, monkeypatch, capsys, tmpdir):
     with (tmpdir / "job.yaml").open("w") as f_out:
         f_out.write("job definition as yaml")
     with (tmpdir / "lavacli.yaml").open("w") as f_conf:
-        f_conf.write(
-            yaml.dump(
-                {
-                    "default": {"uri": "https://lava.example.com/RPC2"},
-                    "admin": {"uri": "https://localhost:8001/RPC2"},
-                }
-            )
+        safe_yaml.dump(
+            {
+                "default": {"uri": "https://lava.example.com/RPC2"},
+                "admin": {"uri": "https://localhost:8001/RPC2"},
+            },
+            f_conf,
         )
     monkeypatch.setattr(
         sys,
